package com.air.applets.controller;

import cn.hutool.core.util.StrUtil;
import com.air.applets.dto.LandDto;
import com.air.applets.vo.LandVo;
import com.air.enums.LandListStatusEnum;
import com.air.land.dto.LandListedDto;
import com.air.land.dto.LandListedStatisticsDto;
import com.air.land.entity.LandListed;
import com.air.land.service.LandListedService;
import com.air.land.service.LandToListService;
import com.air.land.vo.LandListedAppletsVo;
import com.air.land.vo.LandListedVo;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDate;
import java.time.Period;
import java.util.List;


/**
 * 已挂牌地块。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
@RestController("applets_landListedController")
@RequestMapping("/applets/landlisted")
@Api(value = "landlisted", tags = "小程序已挂牌地块据管理")
@Slf4j
public class LandListedController {

    @Autowired
    private LandListedService landListedService;

    @Autowired
    private LandToListService landToListService;

    /**
     * 地块列表分页查询
     *
     * @param queryPage 分页对象
     * @param landVo    查询参数
     * @return
     */
    @ApiOperation(value = "地块列表分页查询", notes = "地块列表分页查询")
    @GetMapping("page")
    public R<Page<LandDto>> getLandListedPage(QueryPage queryPage, LandVo landVo) {
        List<LandDto> landDtos;
        Page<LandDto> page = queryPage.toPage();
        if (LandListStatusEnum.TO_BE_LISTED.getCode().equals(landVo.getTransactionStatus())) {
            if (StrUtil.isNotEmpty(landVo.getStartDate()) || StrUtil.isNotEmpty(landVo.getEndDate())) {
                return R.ok();
            }
            //交易状态为 待挂牌时，查询拟挂牌地块数据
            landDtos = landToListService.appletsLandToList(page, landVo);
        } else {
            landDtos = landListedService.appletsLandListed(page, landVo);
        }
        return R.ok(page.setRecords(landDtos), "查询成功");
    }

    /**
     * 查询已挂牌地块信息列表
     *
     * @param appletsVo 查询参数
     * @return R
     */
    @ApiOperation(value = "查询已挂牌地块信息列表", notes = "查询已挂牌地块信息列表")
    @GetMapping("/list")
    public R<Page<LandListedDto>> getLandListedByDate(QueryPage page, LandListedAppletsVo appletsVo) {
        if (StringUtils.isEmpty(appletsVo.getAnnoDate()) && StringUtils.isEmpty(appletsVo.getAuctionDate())) {
            return R.failed("公告日期或拍卖日期为空");
        }
        if (StringUtils.isNotEmpty(appletsVo.getAnnoDate()) && StringUtils.isNotEmpty(appletsVo.getAuctionDate())) {
            return R.failed("公告日期和拍卖日期只填之一");
        }
        return landListedService.getLandListedByDate(page, appletsVo);
    }

    /**
     * 已挂牌地块详细查询接口
     *
     * @param landListedId
     * @return R
     */
    @ApiOperation(value = "已挂牌地块详细查询接口", notes = "通过id已挂牌地块详细查询接口")
    @GetMapping("/{landListedId}")
    public R<LandListed> getById(@PathVariable("landListedId") String landListedId) {
        LandListed landListed = landListedService.getById(landListedId);
        if (landListed == null){
            return R.failed("landListedId不正确");
        }
        LocalDate localDate = LocalDate.now();
        if (StrUtil.equals(landListed.getDeal(),"1")){
            landListed.setTransactionStatus(LandListStatusEnum.DEAL_DONE.getCode());
        }else if (StrUtil.equals(landListed.getDeal(),"0")){
            landListed.setTransactionStatus(LandListStatusEnum.PASS_BY.getCode());
        }else if (!localDate.isAfter(landListed.getAuctionDate())){
            landListed.setTransactionStatus(LandListStatusEnum.LISTED.getCode());
        }else if (localDate.isAfter(landListed.getAuctionDate())){
            landListed.setTransactionStatus(LandListStatusEnum.DEAL_DONE.getCode());
        }
        return R.ok(landListed);
    }

    /**
     * 按日期统计地块数量
     *
     * @param appletsVo 查询参数
     * @return R
     */
    @ApiOperation(value = "按日期统计地块数量", notes = "按日期统计地块数量")
    @GetMapping("/statistics")
    public R<LandListedStatisticsDto> appletsStatistics(LandListedAppletsVo appletsVo) {
        if (StringUtils.isEmpty(appletsVo.getDate())) {
            return R.failed("查询日期不能为空");
        }
        return landListedService.appletsStatistics(appletsVo);
    }

    /**
     * 按日期统计地块数量(日历)
     * @author peihao
     * @param date 日期(yyyy-MM）
     * @param city 城市
     * @date 2021/7/9
     * @return
     **/
    @ApiOperation(value = "按日期统计地块数量(日历)", notes = "按日期统计地块数量(日历)")
    @GetMapping("/calendar")
    public R<List<LandListedStatisticsDto>> appletsCalendar(@RequestParam String date , String city,String canton) {
        log.info("=================={}===={}=={}"+date,city,canton);
        return landListedService.appletsCalendar(date,city,canton);
    }

}



































